summaryrefslogtreecommitdiff
path: root/src/mongo/client/dbclient_connection.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/mongo/client/dbclient_connection.h')
-rw-r--r--src/mongo/client/dbclient_connection.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/mongo/client/dbclient_connection.h b/src/mongo/client/dbclient_connection.h
index 02465fa8387..9187852758d 100644
--- a/src/mongo/client/dbclient_connection.h
+++ b/src/mongo/client/dbclient_connection.h
@@ -76,13 +76,13 @@ class DBClientCursorBatchIterator;
class DBClientConnection : public DBClientBase {
public:
/**
* A hook used to validate the reply of a "hello" command during connection. If the hook
* returns a non-OK Status, the DBClientConnection object will disconnect from the remote
* server. This function must not throw - it can only indicate failure by returning a non-OK
* status.
*/
using HandshakeValidationHook =
- std::function<Status(const executor::RemoteCommandResponse& helloReply)>;
+ std::function<Status(const executor::RemoteCommandResponse& isMasterReply)>;
/**
@param _autoReconnect if true, automatically reconnect on a connection failure
@@ -125,8 +125,8 @@ public:
boost::optional<TransientSSLParams> transientSSLParams);
/**
* This version of connect does not run "hello" after creating a TCP connection to the
* remote host. This method should be used only when calling "hello" would create a deadlock,
* such as in 'isSelf'.
*
* @param server The server to connect to.
@@ -76,13 +76,13 @@ class DBClientCursorBatchIterator;
public:
/**
- * A hook used to validate the reply of a "hello" command during connection. If the hook
+ * A hook used to validate the reply of an 'isMaster' command during connection. If the hook
* returns a non-OK Status, the DBClientConnection object will disconnect from the remote
* server. This function must not throw - it can only indicate failure by returning a non-OK
@@ -125,8 +125,8 @@ public:
boost::optional<TransientSSLParams> transientSSLParams);
/**
- * This version of connect does not run "hello" after creating a TCP connection to the
- * remote host. This method should be used only when calling "hello" would create a deadlock,
+ * This version of connect does not run 'isMaster' after creating a TCP connection to the
+ * remote host. This method should be used only when calling 'isMaster' would create a deadlock,
* such as in 'isSelf'.
*